=================
Telemeta - README
=================

Telemeta: web frontend to backup, analyse, transcode and stream any audio content and metadata


Introduction
============

Telemeta is a web audio archiving program which introduces useful and secure methods to
backup, index, transcode, analyse and publish any digitalized audio file with its metadata.
It is dedicated to professionnals who wants to easily backup and publish documented sounds
from collections of vinyls, magnetic tapes or audio CDs over a strong database,
in accordance with open standards.

Here are the main features of Telemeta:

    * Secure archiving, editing and publishing of audio files over internet.
    * User friendly web frontend including workflows and high level search methods
    * Smart dynamical and skinnable audio player (thanks to Timeside and soundmanager2)
    * "On the fly" analyzing, transcoding and metadata embedding based on an easy plugin architecture
    * Multi-format support : FLAC, OGG, MP3, WAV and more
    * GEO Navigator for audio geolocalization
    * DublinCore compatibility
    * OAI-PMH data provider
    * XML serialized backup
    * Strong SQL backend

The Telemeta data model is based on 'collections' and 'items'. A collection is described
by its metadata and includes original audio items (sounds) and its own metadata. This
existing model has been designed to fit the one of the French Centre of Etnomusicology (CREM)
but could be easily adapted/overrided to sue other data structures.


Installation and usage
======================

See INSTALL and http://telemeta.org for more informations.


Development
===========

To participate to the development of telemeta, you will need a login/password couple.
You're welcome to email us to join and commit your great ideas ;)

To get the lastest development version, you need subversion and run::

    $ svn co http://svn.parisson.org/svn/telemeta/trunk telemeta


Licence
=======
CeCILL v2 (see COPYING)


Bugs and feedback
=================

You are welcome to freely use this application in accordance to its licence.
If you find some bugs, PLEASE leave a ticket on this page:

http://telemeta.org/newticket

You can also leave a ticket to request some new interesting features for the next versions.
And even if Telemeta suits you, please give us some feedback !


Related projects
================

TimeSide : Web Audio Components
http://code.google.com/p/timeside/


Contact
=======

:Homepage:    http://telemeta.org

:Emails:      Guillaume Pellerin <yomguy@parisson.com>,
              Olivier Guilyardi <olivier@samalyse.com>,
              Riccardo Zaccarelli <riccardo.zaccarelli@gmail.com>

Sponsors
========

The Telemeta project is developed by Parisson and Samalyse. It is sponsored by :

  * CNRS : Centre National de la Recherche Scientifique (the french Natianal Research and Scientific Center)
    http://cnrs.fr
  * CREM : Centre de Recherche en Ethnomusicology (the french Ethnomusicology Research Center)
    http://www.crem-cnrs.fr
  * LAM : Equipe Lutherie, Acoustique et Musique de l'Université Pierre et Marie Curie de Paris
    (Instrument design, Acoustic and Music team of the Pierre & Marie Curie University)
    http://www.lam.jussieu.fr/
  * MuCEM : Musée des Civilisations de l'Europe et de la Méditerranée
    http://www.musee-europemediterranee.org
  * MMSH : Maison Méditerranéenne des Sciences de l'Homme
    http://www.mmsh.univ-aix.fr/
  *  The Antropponet Project (ended)
